@@ -403,11 +403,17 @@ def to_datetime_str(s: Any = None,
     r_s = to_datetime(s, pattern=pattern, tz=tz, r_str=False, default_tz=default_tz)
     if pattern_str is None:
         iso_str = r_s.isoformat()
-        if '.' in iso_str:
-            parts = iso_str.split('.')
-            # 只保留3位毫秒
-            millisecond_part = parts[1][:3]
-            return parts[0] + '.' + millisecond_part + parts[1][3 + 3:]  # 跳过时区部分
+        if '.' not in iso_str:
+            # '2025-10-09T10:52:41+08:00'
+            iso_str = iso_str[0:-6] + '.000' + iso_str[-6:]
+        parts = iso_str.split('.')
+        time_zone_part = parts[1]
+        time_zone_str = tz
+        millisecond_part = time_zone_part[:3]
+        for a in ['+', '-']:
+            if a in time_zone_part:
+                time_zone_str = a + time_zone_part.split(a)[-1]
+        return parts[0] + '.' + millisecond_part + time_zone_str
     else:
         return r_s.strftime(pattern_str)
 
